@@ -1,10 +1,14 @@
 # -*- coding: utf-8 -*-
 
-from mathics_scanner.load import load_mathics_character_yaml, load_mathics_character_json
+from mathics_scanner.load import (
+    load_mathics_character_yaml,
+    load_mathics_character_json,
+)
 
 yaml_data = load_mathics_character_yaml()
 json_data = load_mathics_character_json()
 
+
 def test_letterlikes_sanity():
     letterlikes = json_data["letterlikes"]
 
